@@ -24,8 +24,8 @@ sub run {
   my $self = shift;
 
   GetOptionsFromArray( \@_,
-    'directory|d=s' => \my $dir,
-    'title|t:s'     => \(my $title = '<!-- %s -->'),
+    'directory=s' => \my $dir,
+    'title:s'     => \(my $title = '<!-- %s -->'),
   );
 
   $title = '# %s' unless $title;
